@@ -136,11 +136,14 @@ def _generate_in_assessment_relations(session):
                                'UNION (Any X,A,N WHERE X is E, E name N, X comments M, '
                                'A %(r)s M))' % {'r': rtype})
         yield ('in_assessment', rset)
-    # Assessment Files
-    rset = session.execute('Any X, A, N WITH X, A, N BEING ('
-                           '(Any X,A,N WHERE X is E, E name N, A configuration_files X) '
-                           'UNION (Any X,A,N WHERE X is E, E name N, A results_files X))')
-    yield ('in_assessment', rset)
+        # Assessment Files
+        rset = session.execute('Any X, A, N WITH X, A, N BEING ('
+                               '(Any X,A,N WHERE X is E, E name N, A %(r)s M, '
+                               'M configuration_files X) '
+                               'UNION (Any X,A,N WHERE X is E, E name N, A %(r)s M, '
+                               'M results_files X))'
+                                % {'r': rtype})
+        yield ('in_assessment', rset)
 
 
 def _generate_of_subject_relations(session):
