@@ -18,34 +18,41 @@
 
 """cubicweb-brainomics views/forms/actions/components for web ui"""
 
-from cubicweb.web import formfields as ff, Redirect
+from cubicweb.web import formfields as ff, Redirect, ValidationError
 import cubicweb.web.formwidgets as fwdgs
-from cubicweb.view import StartupView
+from cubicweb.view import AnyRsetView
 from cubicweb.web.views.basecontrollers import ViewController
 from cubicweb.web.views import forms
+from cubicweb.web.action import Action
 
-BROWSABLE_ENTITIES = ('Subject', 'Scan')
 
-class BrainomicsDisplaySpecificEntities(StartupView):
-    __regid__ = 'display-specific-entities'
+###############################################################################
+### BROWSER LIST ##############################################################
+###############################################################################
+BROWSABLE_ENTITIES = {'Subject': 'identifier'}
+
+
+class BrainomicsBrowseEntityList(AnyRsetView):
+    __regid__ = 'browse-list'
 
     def call(self):
         self.w(u'<div class="col-md-12">')
-        self.w(u'<h2>Display specific entities</h2>')
-        self.w(u'<legend>%s</legend>' % self._cw._('Browse for identifiers file'))
-        entities_form = self._cw.vreg['forms'].select('browse-identifiers-form', self._cw)
+        self.w(u'<h2>%s</h2>' % self._cw._('Browse entities list'))
+        self.w(u'<div class="well">%s</div>'
+               % self._cw._('Browse for a list of entities using a CSV file. The CSV file should have '
+                            'only one identifier by line.'))
+        entities_form = self._cw.vreg['forms'].select('browse-list-form', self._cw)
         entities_form.render(w=self.w)
         self.w(u'</div>')
 
 
-class BrainomicsDisplaySpecificEntitiesForm(forms.FieldsForm):
-    __regid__ = 'browse-identifiers-form'
+class BrainomicsBrowseEntityListForm(forms.FieldsForm):
+    __regid__ = 'browse-list-form'
     form_buttons = [fwdgs.SubmitButton(label=_('Validate'), attrs={"class": "btn btn-primary"})]
 
-
     @property
     def action(self):
-        return self._cw.build_url('browse-identifiers-controller')
+        return self._cw.build_url('browse-list-controller')
 
     filename = ff.FileField(name='__file',
                             label=_('Indentifiers file to import'),
@@ -56,21 +63,19 @@ class BrainomicsDisplaySpecificEntitiesForm(forms.FieldsForm):
                            required=True,
                            help=_('Entity type'),
                            order = 2,
-                           choices = BROWSABLE_ENTITIES)
+                           choices = BROWSABLE_ENTITIES.keys())
 
 
-class BrainomicsDisplaySpecificEntitiesController(ViewController):
-    __regid__ = 'browse-identifiers-controller'
+class BrainomicsBrowseEntityListController(ViewController):
+    __regid__ = 'browse-list-controller'
 
     def _read_uuid_file(self, filename):
         try:
             fdesc = filename[1]
         except IOError as ioerr:
-            sys.stderr.write('File not found')
-            uuids = None
+            raise ValidationError(None, 'File not found')
         else:
             uuids = ["'" + uuid.strip() + "'" for uuid in fdesc.readlines() if uuid.strip()]
-            fdesc.close()
         return uuids
 
     def publish(self, rset=None):
@@ -78,7 +83,17 @@ class BrainomicsDisplaySpecificEntitiesController(ViewController):
         etype = self._cw.form['__etype']
         uuids = self._read_uuid_file(filename)
         if uuids:
-            rql = ('Any X WHERE X is %(etype)s, X identifier IN (%(uuids)s)'
-                   % {'uuids': ', '.join(uuids), 'etype': etype})
+            rql = ('Any X WHERE X is %(etype)s, X %(ident)s IN (%(uuids)s)'
+                   % {'uuids': ', '.join(uuids), 'etype': etype,
+                      'ident': BROWSABLE_ENTITIES[etype]})
             raise Redirect(self._cw.build_url(vid='list', rql=rql))
         raise Redirect(self._cw.base_url())
+
+
+class BrainomicsBrowseEntityListAction(Action):
+    __regid__ = 'browse-list-action'
+    category = 'browse-links'
+    title = _('Browse from list')
+
+    def url(self):
+        return self._cw.build_url(vid='browse-list')
