@@ -32,6 +32,8 @@ from cubes.brainomics.views.download import ALL_DOWNLOADABLE
 
 LINKED_ENTITIES = ('Subject',)
 
+_ = unicode
+
 
 ###############################################################################
 ### NAVIGATION BOXES ##########################################################
@@ -176,14 +178,14 @@ class BrainomicsEditBox(EditBox):
     def render(self, w, **kwargs):
         actions = self.get_actions()
         if actions:
-            w(u'<div class="well">')
+            w(u'<div class="well admintools">')
             w(u'<h4>%s</h4>' % self._cw._('Administration tools'))
             for action in actions:
                 if hasattr(action, 'title'):
                     icon = getattr(action, 'icon', 'edit')
                     title = self._cw._(action.title)
                     w(u'<a class="btn btn-primary btn-block" href="%s">' % action.url())
-                    w(u'<i class="glyphicon-%s glyphicon-white"></i>%s</a>' % (icon, title))
+                    w(u'<i class="glyphicon glyphicon-%s"></i> %s</a>' % (icon, title))
             w(u'</div>')
 
 
@@ -200,14 +202,14 @@ class BrainomicsDownloadBox(component.CtxComponent):
         possible_actions = self._cw.vreg['actions'].possible_actions(self._cw, self.cw_rset)
         links = list(possible_actions.get('download-links', []))
         if links:
-            w(u'<div class="well">')
+            w(u'<div class="well admintools">')
             w(u'<h4>%s</h4>' % self._cw._('Download tools'))
             for link in links:
                 url = self._cw.build_url(rql=self.cw_rset.printable_rql(), vid=link.download_vid)
                 _id = link.__regid__
                 w(u'<a class="btn btn-primary btn-block download-ctx" id="%s" href="%s">'
                   % (_id, url))
-                w(u'<i class="glyphicon glyphicon-download"></i>%s</a>' % self._cw._(link.title))
+                w(u'<i class="glyphicon glyphicon-download"></i> %s</a>' % self._cw._(link.title))
             w(u'</div>')
             # Add on load the rql facet change
             self._cw.add_onload("""$(cw).bind('facets-content-loaded',
@@ -218,20 +220,23 @@ class BrainomicsDownloadBox(component.CtxComponent):
 ### DATA BOXES ################################################################
 ###############################################################################
 class BrainomicsResultsFileBox(component.CtxComponent):
-    __select__ = (component.CtxComponent.__select__ & nonempty_rset()
-                  & relation_possible('results_file') & one_line_rset())
+    __select__ = (component.CtxComponent.__select__ & nonempty_rset() & one_line_rset()
+                  & relation_possible('results_files'))
     context = 'left'
+    __regid__ = 'ctx-results-files-box'
     order = 2
-    __regid__ = 'ctx-data-box'
+    rtype = 'results_files'
+    title = _('Results files')
 
     def render(self, w, **kwargs):
         entity = self.cw_rset.get_entity(0, 0)
-        if not entity.results_file:
+        _files = getattr(entity, self.rtype)
+        if not _files:
             return
         w(u'<div class="well">')
-        w(u'<h4>%s</h4>' % self._cw._('Results files'))
+        w(u'<h4>%s</h4>' % self._cw._(self.title))
         w(u'<ul>')
-        for _file in entity.results_file:
+        for _file in _files:
             title = _file.dc_title().rsplit('/')[-1]
             w(u'<li>%s<a href="%s" title="%s">%s</a></li>'
               % (_file.view('icon'), _file.absolute_url(),
@@ -240,6 +245,15 @@ class BrainomicsResultsFileBox(component.CtxComponent):
         w(u'</div>')
 
 
+class BrainomicsConfigurationFileBox(BrainomicsResultsFileBox):
+    __select__ = (component.CtxComponent.__select__ & nonempty_rset() & one_line_rset()
+                  & relation_possible('configuration_files'))
+    __regid__ = 'ctx-configuration-files-box'
+    rtype = 'configuration_files'
+    title = _('Configuration files')
+    order = 3
+
+
 ###############################################################################
 ### FACETS/FORMWIDGETS ########################################################
 ###############################################################################
