@@ -50,6 +50,8 @@ class BrainomicsAdmissionView(EntityView):
         w(u'<div class="panel-heading">%s (%s %s)</div>' % (entity.dc_title(),
                                                             self._cw._('see study'),
                                                             entity.admission_in[0].view('incontext')))
+        w(u'<div class="panel-body">%s: %s %s</div>'
+          % (self._cw._('Subject age'), entity.subject_age, self._cw._('years')))
         w(u'<div class="panel-body">')
         w(u'<ul>')
         for step in entity.reverse_step_of:
@@ -94,9 +96,34 @@ class BrainomicsResultFile(EntityView):
             self.wview('list', rset=rset)
 
 
-###############################################################################
-### AGGREGATED VIEW ###########################################################
-###############################################################################
+class AnatomicPathologyReportView(EntityView):
+    __regid__ = 'clinipath-reports'
+    __select__ = EntityView.__select__ & is_instance('AnatomicPathologyReport')
+
+    def call(self, rset=None):
+        w = self.w
+        w(u'<div class="panel-group" id="biopsy-reports">')
+        for entity in self.cw_rset.entities():
+            self.entity_call(entity)
+        w(u'</div>')
+        # Js
+        self._cw.add_onload('$(".collapse").collapse()')
+
+    def entity_call(self, entity):
+        w = self.w
+        w(u'<div class="panel panel-default">')
+        w(u'<div class="panel-heading">')
+        w(u'<h4 class="panel-title">')
+        w(u'<a data-toggle="collapse" data-parent="#biopsy-reports" href="#report-%s">%s</a>'
+          % (entity.eid, entity.formatted_title))
+        w(u'</h4>')
+        w(u'</div>')
+        w(u'<div id="report-%s" class="panel-collapse collapse in">' % entity.eid)
+        w(u'<div class="panel-body">%s</div>' % entity.formatted_content)
+        w(u'</div>')
+        w(u'</div>')
+
+
 class BrainomicsAggregatedView(EntityView):
     __regid__ = 'aggregated-view'
 
