@@ -71,7 +71,7 @@ _pvs.tag_subject_of(('*', 'therapy_for', 'Disease'), 'attributes')
 _pvs.tag_object_of(('*', 'related_therapies', 'Therapy'), 'attributes')
 _pvs.tag_subject_of(('Therapy', 'therapy_for', '*'), 'attributes')
 _pvs.tag_object_of(('*', 'taken_in_therapy', 'Therapy'), 'relations')
-_pvdc.tag_object_of(('*', 'taken_in_therapy', 'Therapy'), {'vid': 'drugtake-table-view'})
+_pvdc.tag_object_of(('*', 'taken_in_therapy', 'Therapy'), {'vid': 'intherapy-drugtake-table-view'})
 
 
 ###############################################################################
@@ -183,10 +183,14 @@ _pvdc.tag_subject_of(('ExternalResource', 'related_study', '*'),
 _pvs.tag_object_of(('*', 'generates', 'GenomicMeasure'), 'attributes')
 _pvs.tag_subject_of(('GenomicMeasure', 'concerns', 'Subject'), 'attributes')
 _pvs.tag_subject_of(('GenomicMeasure', 'related_study', 'Study'), 'attributes')
-_pvs.tag_subject_of(('GenomicMeasure', 'platform', '*'), 'attributes')
+_pvs.tag_subject_of(('GenomicMeasure', 'chip', '*'), 'attributes')
 _pvs.tag_object_of(('*', 'related_measure', 'GenomicMeasure'), 'relations')
 _pvdc.tag_object_of(('*', 'related_measure', 'GenomicMeasure'),
                     {'label': _('Results'), 'vid': 'genmeas-table-view'})
+_pvs.tag_object_of(('GenomicMeasure', 'chip', 'Chip'), 'relations')
+_pvdc.tag_object_of(('GenomicMeasure', 'chip', 'Chip'), {'vid': 'table'})
+_pvs.tag_object_of(('Chip', 'platform', 'GenomicPlatform'), 'relations')
+_pvdc.tag_object_of(('Chip', 'platform', 'GenomicPlatform'), {'vid': 'table'})
 
 
 ###############################################################################
@@ -215,6 +219,8 @@ _pvdc.tag_object_of(('*', 'related_gene', 'Gene'),
 ###############################################################################
 # Genes
 _pvs.tag_subject_of(('GenomicRegion', 'genes', '*'), 'attributes')
+_pvs.tag_subject_of(('GenomicRegion', 'left_gene', '*'), 'attributes')
+_pvs.tag_subject_of(('GenomicRegion', 'right_gene', '*'), 'attributes')
 # CGH results
 _pvs.tag_object_of(('*', 'genomic_region', 'GenomicRegion'), 'relations')
 _pvdc.tag_object_of(('*', 'genomic_region', 'GenomicRegion'),
@@ -304,3 +310,28 @@ _pvs.tag_subject_of(('Drug', 'acts_on', '*'), 'relations')
 _pvs.tag_subject_of(('BodyLocation', 'subpart_of', '*'), 'attributes')
 _pvs.tag_object_of(('Diagnostic', 'diagnostic_location', 'BodyLocation'), 'relations')
 _pvs.tag_object_of(('Diagnostic', 'metastatic_locations', 'BodyLocation'), 'relations')
+
+
+###############################################################################
+### CLINIPATH #################################################################
+###############################################################################
+_pvs.tag_object_of(('Subject', 'related_samples', '*'), 'attributes')
+_pvs.tag_object_of(('AnatomicPathologyReport', 'report_on', '*'), 'relations')
+_pvdc.tag_object_of(('AnatomicPathologyReport', 'report_on', '*'), {'vid': 'clinipath-reports'})
+_pvdc.display_rset('Biopsy', 'relations', {'rql': ('Any D WHERE D is TechnicalAnalysis, '
+                                                   'D performed_on X, NOT D performed_in_therapy T'),
+                                           'vid': 'analysis-table-view',
+                                           'order': 4,
+                                           'label': _('Analysis')})
+_pvdc.display_rset('Biopsy', 'relations', {'rql': ('Any D WHERE D is Diagnostic, '
+                                                   'D based_on X, NOT D leads_to_therapies T'),
+                                           'vid': 'diagnostics-table-view',
+                                           'order': 2,
+                                           'label': _('Diagnostics of sampling')})
+_pvs.tag_subject_of(('Subject', 'related_samples', '*'), 'hidden')
+_pvdc.display_rset('Subject', 'relations', {'rql': 'Any B WHERE B is Biopsy, X related_samples B',
+                                           'vid': 'list',
+                                           'label': _('Related samples')})
+_pvs.tag_object_of(('BiopsySample', 'extracted_from', 'Biopsy'), 'relations')
+_pvdc.tag_object_of(('BiopsySample', 'extracted_from', 'Biopsy'),
+                    {'order': 3, 'vid': 'biopsysample-table-view'})
